@@ -2,7 +2,7 @@
  * 
  * hlist.c -
  * 
- * $Id: hlist.c,v 1.51 2001/03/11 16:02:45 furukawa Exp $
+ * $Id: hlist.c,v 1.51.4.3 2001/09/08 07:42:02 takesako Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -28,7 +28,6 @@
  */
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <math.h>
 #include <errno.h>
 #ifdef HAVE_CONFIG_H
@@ -37,13 +36,21 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
-#if defined (HAVE_UNISTD_H)
+
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #else
-# if defined (_WIN32) && !defined (__CYGWIN__)
+# ifdef _WIN32
 # include <io.h>
 # endif
 #endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include "libnamazu.h"
 #include "util.h"
 #include "hlist.h"
@@ -239,24 +246,25 @@ nmz_andmerge(NmzResult left, NmzResult right, int *ignore)
 {
     int i, j, v;
 
-    if (ignore && *ignore && left.num > 0) {
-	nmz_free_hlist(right);
-	return left;
-    }
-    if (ignore && *ignore && right.num > 0) {
+    if (left.stat == ERR_TOO_MUCH_MATCH || left.stat == ERR_TOO_MUCH_HIT) {
 	nmz_free_hlist(left);
 	return right;
     }
 
-    if (left.stat != SUCCESS || left.num <= 0) {
-	nmz_free_hlist(left);
-	return right;
-    }
-    if (right.stat != SUCCESS || right.num <= 0) {
+    if (right.stat == ERR_TOO_MUCH_MATCH || right.stat == ERR_TOO_MUCH_HIT) {
 	nmz_free_hlist(right);
 	return left;
     }
 
+    if (left.stat != SUCCESS || left.num <= 0) {
+	nmz_free_hlist(right);
+	return left;
+    }
+    if (right.stat != SUCCESS || right.num <= 0) {
+	nmz_free_hlist(left);
+	return right;
+    }
+
     for (v = 0, i = 0, j = 0; i < left.num; i++) {
 	for (;; j++) {
 	    if (j >= right.num)
