@@ -7,7 +7,7 @@ package conf;  # Don't remove this line!
 #
 # Administrator's email address
 #
-$ADDRESS = 'webmaster@kili.eal.or.jp';
+$ADDRESS = 'webmaster@elmo.local';
 
 
 #===================================================================
@@ -32,7 +32,7 @@ $ALLOW_FILE =	".*\\.(?:$HTML_SUFFIX)|.*\\.txt" . # HTML, plain text
 		"|.*\\.tex|.*\\.dvi" .   	   # TeX, DVI
 		"|.*\\.rpm|.*\\.deb" .   	   # RPM, DEB
 		"|.*\\.doc|.*\\.xls|.*\\.ppt" .	   # Word, Excel, PowerPoint
-		"|.*\\.j[sab]w" .                  # Ichitaro 4, 5, 6
+		"|.*\\.j[sabf]w|.*\\.jtd" .        # Ichitaro 4, 5, 6, 7, 8
 		"|\\d+|[-\\w]+\\.[1-9n]";          # Mail/News, man
 
 #
@@ -183,12 +183,12 @@ $KAKASI = "module_kakasi -ieuc -oeuc -w";
 #
 # ChaSen 1.51 or later (simple wakatigaki)
 #
-$CHASEN = "module_chasen -j -F '\%m '";
+$CHASEN = "no";
 
 #
 # ChaSen 1.51 or later (with noun words extraction)
 #
-$CHASEN_NOUN = "module_chasen -j -F '\%m %H\\n'";
+$CHASEN_NOUN = "no";
 
 #
 # Default Japanese processer: KAKASI or ChaSen.
