@@ -1,5 +1,5 @@
 /*
- * $Id: output.c,v 1.80.4.2 2001/07/31 06:11:03 knok Exp $
+ * $Id: output.c,v 1.80.4.4 2001/09/12 04:50:42 takesako Exp $
  * 
  * Copyright (C) 1997-1999 Satoru Takabayashi All rights reserved.
  * Copyright (C) 2000 Namazu Project All rights reserved.
@@ -25,7 +25,6 @@
 #include <errno.h>
 #include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 #include <ctype.h>
 #include <stdarg.h>
 #ifdef HAVE_CONFIG_H
@@ -34,6 +33,13 @@
 #ifdef HAVE_SUPPORT_H
 #  include "support.h"
 #endif
+
+#ifdef HAVE_STRING_H
+#include <string.h>
+#else
+#include <strings.h>
+#endif
+
 #include "namazu.h"
 #include "libnamazu.h"
 #include "codeconv.h"
@@ -481,11 +487,11 @@ print_page_index(int n)
     int i, max, whence;
     char *qs; /* QUERY_STRING */
     char *sn; /* SCRIPT_NAME  */
-    char *dn; /* DOCUMENT_NAME  */
+    char *dn; /* DOCUMENT_URI  */
 
     qs = nmz_getenv("QUERY_STRING");
     sn = nmz_getenv("SCRIPT_NAME");
-    dn = nmz_getenv("DOCUMENT_NAME");
+    dn = nmz_getenv("DOCUMENT_URI");
 
     if(dn == NULL || *dn == '\0') 
         dn=sn;
